@@ -12,12 +12,12 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::Compile;
 {
-  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.015';
+  $Dist::Zilla::Plugin::Test::Compile::VERSION = '2.016';
 }
 # ABSTRACT: common tests to check syntax of your modules
 
 use Moose;
-use File::Spec;
+use Path::Tiny;
 use Data::Section -setup;
 with (
     'Dist::Zilla::Role::FileGatherer',
@@ -112,9 +112,9 @@ sub gather_files {
 
     my @skips = map {; qr/$_/ } $self->skips;
 
-    # we strip the leading lib/ so the %INC entry is correct - to avoid
-    # potentially loading the file again later
-    my @module_filenames = map { File::Spec->abs2rel($_, 'lib') } $self->_module_filenames;
+    # we strip the leading lib/, and convert win32 \ to /, so the %INC entry
+    # is correct - to avoid potentially loading the file again later
+    my @module_filenames = map { path($_)->relative('lib')->stringify } $self->_module_filenames;
 
     @module_filenames = grep {
         (my $module = $_) =~ s{[/\\]}{::}g;
@@ -165,7 +165,7 @@ Dist::Zilla::Plugin::Test::Compile - common tests to check syntax of your module
 
 =head1 VERSION
 
-version 2.015
+version 2.016
 
 =head1 SYNOPSIS
 
